#' Some animals, their types and their masses
#'
#' @format A data frame with 6 rows and 4 variables:
#' \describe{
#'   \item{animal}{the name of the animal} 
#'   \item{type}{the type of animal} 
#'   \item{flies}{whether the animal can fly} 
#'   \item{mass}{the average mass of the animal in grams} 
#' }
"animals"

#' The compositions of some espresso-based beverages
#'
#' @format A data frame with 6 rows and 3 variables:
#' \describe{
#'   \item{beverage}{the name of the beverage} 
#'   \item{ingredient}{the ingredient} 
#'   \item{proportion}{the proportion of a cup to fill with the ingredient} 
#' }
"beverages"

#' Some craft and their altitudes
#'
#' @format A data frame with 4 rows and 2 variables:
#' \describe{
#'   \item{craft}{the name of the craft} 
#'   \item{altitude}{the craft's normal cruising altitude in metres}
#' }
"altitudes"

#' Robert Frost's poem *Nothing Gold Can Stay* (1923)
#'
#' @format A data frame with 8 rows and 5 variables:
#' \describe{
#'   \item{line}{a line from the poem} 
#'   \item{xmin}{the xmin coordinate with which to draw the word} 
#'   \item{xmax}{the xmax coordinate with which to draw the word} 
#'   \item{ymin}{the ymin coordinate with which to draw the word} 
#'   \item{ymax}{the ymax coordinate with which to draw the word} 
#'   \item{linenumber}{the line number} 
#' }
"gold"
